@@ -9,7 +9,9 @@
 #include <common.h>
 #include <dm.h>
 #include <env.h>
+#include <fastboot.h>
 #include <init.h>
+#include <asm/global_data.h>
 #include <linux/ctype.h>
 #include <linux/usb/musb.h>
 #include <asm/omap_musb.h>
@@ -29,18 +31,19 @@ const omap3_sysinfo sysinfo = {
 	.nand_string = "MMC"
 };
 
-static const struct ns16550_platdata serial_omap_platdata = {
+static const struct ns16550_plat serial_omap_plat = {
 	.base = OMAP34XX_UART3,
 	.reg_shift = 2,
 	.clock = V_NS16550_CLK,
 	.fcr = UART_FCR_DEFVAL,
 };
 
-U_BOOT_DEVICE(sniper_serial) = {
+U_BOOT_DRVINFO(sniper_serial) = {
 	.name = "ns16550_serial",
-	.platdata = &serial_omap_platdata
+	.plat = &serial_omap_plat
 };
 
+#if defined(CONFIG_USB_MUSB_HOST) || defined(CONFIG_USB_MUSB_GADGET)
 static struct musb_hdrc_config musb_config = {
 	.multipoint = 1,
 	.dyn_fifo = 1,
@@ -59,6 +62,7 @@ static struct musb_hdrc_platform_data musb_platform_data = {
 	.platform_ops = &omap2430_ops,
 	.board_data = &musb_board_data,
 };
+#endif
 
 void set_muxconf_regs(void)
 {
@@ -145,8 +149,9 @@ int misc_init_r(void)
 	omap_die_id_serial();
 
 	/* MUSB */
-
+#if defined(CONFIG_USB_MUSB_HOST) || defined(CONFIG_USB_MUSB_GADGET)
 	musb_register(&musb_platform_data, &musb_board_data, (void *)MUSB_BASE);
+#endif
 
 	return 0;
 }
@@ -175,12 +180,15 @@ void reset_misc(void)
 	omap_reboot_mode_store(reboot_mode);
 }
 
-int fastboot_set_reboot_flag(void)
+int fastboot_set_reboot_flag(enum fastboot_reboot_reason reason)
 {
+	if (reason != FASTBOOT_REBOOT_REASON_BOOTLOADER)
+		return -ENOTSUPP;
+
 	return omap_reboot_mode_store("b");
 }
 
-int board_mmc_init(bd_t *bis)
+int board_mmc_init(struct bd_info *bis)
 {
 	return omap_mmc_init(1, 0, 0, -1, -1);
 }
