@@ -12,6 +12,7 @@
 #include <log.h>
 #include <spi.h>
 #include <malloc.h>
+#include <asm/global_data.h>
 #include <asm/io.h>
 #include <asm/arch/hardware.h>
 #include <dm.h>
@@ -333,8 +334,8 @@ static int davinci_spi_set_mode(struct udevice *bus, uint mode)
 
 static int davinci_spi_claim_bus(struct udevice *dev)
 {
-	struct dm_spi_slave_platdata *slave_plat =
-		dev_get_parent_platdata(dev);
+	struct dm_spi_slave_plat *slave_plat =
+		dev_get_parent_plat(dev);
 	struct udevice *bus = dev->parent;
 	struct davinci_spi_slave *ds = dev_get_priv(bus);
 
@@ -358,8 +359,8 @@ static int davinci_spi_xfer(struct udevice *dev, unsigned int bitlen,
 			    const void *dout, void *din,
 			    unsigned long flags)
 {
-	struct dm_spi_slave_platdata *slave =
-		dev_get_parent_platdata(dev);
+	struct dm_spi_slave_plat *slave =
+		dev_get_parent_plat(dev);
 	struct udevice *bus = dev->parent;
 	struct davinci_spi_slave *ds = dev_get_priv(bus);
 
@@ -383,7 +384,7 @@ static const struct dm_spi_ops davinci_spi_ops = {
 static int davinci_spi_probe(struct udevice *bus)
 {
 	struct davinci_spi_slave *ds = dev_get_priv(bus);
-	struct davinci_spi_platdata *plat = bus->platdata;
+	struct davinci_spi_plat *plat = dev_get_plat(bus);
 	ds->regs = plat->regs;
 	ds->num_cs = plat->num_cs;
 
@@ -393,10 +394,10 @@ static int davinci_spi_probe(struct udevice *bus)
 #if CONFIG_IS_ENABLED(OF_CONTROL) && !CONFIG_IS_ENABLED(OF_PLATDATA)
 static int davinci_ofdata_to_platadata(struct udevice *bus)
 {
-	struct davinci_spi_platdata *plat = bus->platdata;
+	struct davinci_spi_plat *plat = dev_get_plat(bus);
 	fdt_addr_t addr;
 
-	addr = devfdt_get_addr(bus);
+	addr = dev_read_addr(bus);
 	if (addr == FDT_ADDR_T_NONE)
 		return -EINVAL;
 
@@ -419,10 +420,10 @@ U_BOOT_DRIVER(davinci_spi) = {
 	.id = UCLASS_SPI,
 #if CONFIG_IS_ENABLED(OF_CONTROL) && !CONFIG_IS_ENABLED(OF_PLATDATA)
 	.of_match = davinci_spi_ids,
-	.ofdata_to_platdata = davinci_ofdata_to_platadata,
-        .platdata_auto_alloc_size = sizeof(struct davinci_spi_platdata),
+	.of_to_plat = davinci_ofdata_to_platadata,
+	.plat_auto	= sizeof(struct davinci_spi_plat),
 #endif
 	.probe = davinci_spi_probe,
 	.ops = &davinci_spi_ops,
-	.priv_auto_alloc_size = sizeof(struct davinci_spi_slave),
+	.priv_auto	= sizeof(struct davinci_spi_slave),
 };
