@@ -9,6 +9,7 @@
 #define __MX7_COMMON_H
 
 #include <linux/sizes.h>
+#include <linux/stringify.h>
 #include <asm/arch/imx-regs.h>
 #include <asm/mach-imx/gpio.h>
 
@@ -29,35 +30,28 @@
 
 #define CONFIG_LOADADDR                 0x80800000
 
-/* allow to overwrite serial and ethaddr */
-#define CONFIG_ENV_OVERWRITE
-
 /* Miscellaneous configurable options */
 #define CONFIG_SYS_CBSIZE		512
 #define CONFIG_SYS_MAXARGS		32
 
-#ifndef CONFIG_SYS_DCACHE_OFF
-#endif
-
 /* UART */
-#define CONFIG_MXC_UART
 
 /* MMC */
-#define CONFIG_BOUNCE_BUFFER
-#define CONFIG_FSL_USDHC
-
-/* Fuses */
-#define CONFIG_MXC_OCOTP
 
 #define CONFIG_ARMV7_SECURE_BASE	0x00900000
 
-#define CONFIG_ARMV7_PSCI_1_0
-
-/* Secure boot (HAB) support */
-#ifdef CONFIG_SECURE_BOOT
-#define CONFIG_CSF_SIZE			0x2000
 #ifdef CONFIG_SPL_BUILD
-#define CONFIG_SPL_DRIVERS_MISC_SUPPORT
+#define CONFIG_SPL_DRIVERS_MISC
+#endif
+
+/*
+ * If we have defined the OPTEE ram size and not OPTEE it means that we were
+ * launched by OPTEE, because of that we shall skip all the low level
+ * initialization since it was already done by ATF or OPTEE
+ */
+#if (CONFIG_OPTEE_TZDRAM_SIZE != 0)
+#ifndef CONFIG_OPTEE
+#define CONFIG_SKIP_LOWLEVEL_INIT
 #endif
 #endif
 
