@@ -7,6 +7,7 @@
 #ifndef __SYSCON_H
 #define __SYSCON_H
 
+#include <dm/ofnode.h>
 #include <fdtdec.h>
 
 /**
@@ -32,7 +33,7 @@ struct syscon_ops {
  *
  * Update: 64-bit is now supported and we have an education crisis.
  */
-struct syscon_base_platdata {
+struct syscon_base_plat {
 	fdt_val_t reg[2];
 };
 #endif
@@ -72,6 +73,19 @@ int syscon_get_by_driver_data(ulong driver_data, struct udevice **devp);
  */
 struct regmap *syscon_get_regmap_by_driver_data(ulong driver_data);
 
+/**
+ * syscon_regmap_lookup_by_phandle() - Look up a controller by a phandle
+ *
+ * This operates by looking up the given name in the device (device
+ * tree property) of the device using the system controller.
+ *
+ * @dev:	Device using the system controller
+ * @name:	Name of property referring to the system controller
+ * @return	A pointer to the regmap if found, ERR_PTR(-ve) on error
+ */
+struct regmap *syscon_regmap_lookup_by_phandle(struct udevice *dev,
+					       const char *name);
+
 /**
  * syscon_get_first_range() - get the first memory range from a syscon regmap
  *
@@ -81,4 +95,11 @@ struct regmap *syscon_get_regmap_by_driver_data(ulong driver_data);
  */
 void *syscon_get_first_range(ulong driver_data);
 
+/**
+ * syscon_node_to_regmap - get regmap from syscon
+ *
+ * @node:		Device node of syscon
+ */
+struct regmap *syscon_node_to_regmap(ofnode node);
+
 #endif
